[Cmake-commits] CMake branch, next, updated. v2.8.7-1958-ge0783d4

Brad King brad.king at kitware.com
Wed Jan 4 09:59:04 EST 2012


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  e0783d4af294866a2e35c255c8af769878fcf6ac (commit)
       via  9ccaeb10f9fd58503c8a7e1535f2c9154e3e8c93 (commit)
       via  230943832180162f18512d721300a106fac54416 (commit)
       via  b6ca96ec95145b453790f519abbbae91cd6c9771 (commit)
       via  f293b73d71c5dbbf053a864b2c2f285ef0834630 (commit)
      from  3684984750196c30e631dfd82e056c8f49af4237 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e0783d4af294866a2e35c255c8af769878fcf6ac
commit e0783d4af294866a2e35c255c8af769878fcf6ac
Merge: 3684984 9ccaeb1
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Wed Jan 4 09:59:01 2012 -0500
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Wed Jan 4 09:59:01 2012 -0500

    Merge topic 'update-libarchive' into next
    
    9ccaeb1 libarchive: Suppress PathScale compiler warnings
    2309438 libarchive: Rename isoent_rr_move_dir parameter isoent => curent
    b6ca96e libarchive: Include linux/types.h before linux/fiemap.h
    f293b73 libarchive: Define _XOPEN_SOURCE=500 on HP-UX


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9ccaeb10f9fd58503c8a7e1535f2c9154e3e8c93
commit 9ccaeb10f9fd58503c8a7e1535f2c9154e3e8c93
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Wed Jan 4 09:57:46 2012 -0500
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Wed Jan 4 09:57:46 2012 -0500

    libarchive: Suppress PathScale compiler warnings
    
    We are not developing libarchive so we do not care about warnings.

diff --git a/Utilities/cmlibarchive/CMakeLists.txt b/Utilities/cmlibarchive/CMakeLists.txt
index a24bb5d..d0460ec 100644
--- a/Utilities/cmlibarchive/CMakeLists.txt
+++ b/Utilities/cmlibarchive/CMakeLists.txt
@@ -49,6 +49,8 @@ SET(SOVERSION "${INTERFACE_VERSION}")
 IF("${CMAKE_C_COMPILER_ID}" MATCHES
     "^(GNU|Clang|XL|VisualAge|SunPro|MIPSpro|HP|Intel)$")
   SET(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -w")
+ELSEIF("${CMAKE_C_COMPILER_ID}" MATCHES "^(PathScale)$")
+  SET(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -woffall")
 ELSEIF(BORLAND)
   SET(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -w-")
 ENDIF()

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=230943832180162f18512d721300a106fac54416
commit 230943832180162f18512d721300a106fac54416
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Wed Jan 4 09:48:41 2012 -0500
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Wed Jan 4 09:48:41 2012 -0500

    libarchive: Rename isoent_rr_move_dir parameter isoent => curent
    
    The PGI compiler confuses parameter name "isoent" with "struct isoent".
    Rename the parameter to "curent" to avoid confusion.

diff --git a/Utilities/cmlibarchive/CMakeLists.txt b/Utilities/cmlibarchive/CMakeLists.txt
index 2352693..a24bb5d 100644
--- a/Utilities/cmlibarchive/CMakeLists.txt
+++ b/Utilities/cmlibarchive/CMakeLists.txt
@@ -250,6 +250,7 @@ LA_CHECK_INCLUDE_FILE("inttypes.h" HAVE_INTTYPES_H)
 LA_CHECK_INCLUDE_FILE("io.h" HAVE_IO_H)
 LA_CHECK_INCLUDE_FILE("langinfo.h" HAVE_LANGINFO_H)
 LA_CHECK_INCLUDE_FILE("limits.h" HAVE_LIMITS_H)
+LA_CHECK_INCLUDE_FILE("linux/types.h" HAVE_LINUX_TYPES_H)
 LA_CHECK_INCLUDE_FILE("linux/fiemap.h" HAVE_LINUX_FIEMAP_H)
 LA_CHECK_INCLUDE_FILE("linux/fs.h" HAVE_LINUX_FS_H)
 LA_CHECK_INCLUDE_FILE("linux/magic.h" HAVE_LINUX_MAGIC_H)
diff --git a/Utilities/cmlibarchive/build/cmake/config.h.in b/Utilities/cmlibarchive/build/cmake/config.h.in
index 71a7801..ff97cbd 100644
--- a/Utilities/cmlibarchive/build/cmake/config.h.in
+++ b/Utilities/cmlibarchive/build/cmake/config.h.in
@@ -603,6 +603,9 @@ typedef uint64_t uintmax_t;
 /* Define to 1 if you have the `link' function. */
 #cmakedefine HAVE_LINK 1
 
+/* Define to 1 if you have the <linux/types.h> header file. */
+#cmakedefine HAVE_LINUX_TYPES_H 1
+
 /* Define to 1 if you have the <linux/fiemap.h> header file. */
 #cmakedefine HAVE_LINUX_FIEMAP_H 1
 
diff --git a/Utilities/cmlibarchive/libarchive/archive_read_disk_entry_from_file.c b/Utilities/cmlibarchive/libarchive/archive_read_disk_entry_from_file.c
index 8ce88b3..fdeb516 100644
--- a/Utilities/cmlibarchive/libarchive/archive_read_disk_entry_from_file.c
+++ b/Utilities/cmlibarchive/libarchive/archive_read_disk_entry_from_file.c
@@ -73,6 +73,9 @@ __FBSDID("$FreeBSD: head/lib/libarchive/archive_read_disk_entry_from_file.c 2010
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
 #endif
+#ifdef HAVE_LINUX_TYPES_H
+#include <linux/types.h>
+#endif
 #ifdef HAVE_LINUX_FIEMAP_H
 #include <linux/fiemap.h>
 #endif

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f293b73d71c5dbbf053a864b2c2f285ef0834630
commit f293b73d71c5dbbf053a864b2c2f285ef0834630
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Wed Jan 4 08:46:49 2012 -0500
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Wed Jan 4 08:46:49 2012 -0500

    libarchive: Define _XOPEN_SOURCE=500 on HP-UX
    
    The HP-UX <wchar.h> header provides 'mbstate_t' in C89/C90 mode only if
    _XOPEN_SOURCE is defined to exactly 500.  Type 'mbstate_t' was
    introduced in C89/C90 Normative Amendment 1, aka C94/C95, adding support
    international character sets.  It is part of C99 but not C89/C90.

diff --git a/Utilities/cmlibarchive/CMakeLists.txt b/Utilities/cmlibarchive/CMakeLists.txt
index 9689b28..2352693 100644
--- a/Utilities/cmlibarchive/CMakeLists.txt
+++ b/Utilities/cmlibarchive/CMakeLists.txt
@@ -75,6 +75,10 @@ IF(WIN32)
   SET(_WIN32_WINNT ${WINVER})
 ENDIF(WIN32)
 
+IF("${CMAKE_C_PLATFORM_ID}" MATCHES "^(HP-UX)$")
+  ADD_DEFINITIONS(-D_XOPEN_SOURCE=500) # Ask wchar.h for mbstate_t
+ENDIF()
+
 #
 INCLUDE(CheckCSourceCompiles)
 INCLUDE(CheckCSourceRuns)

-----------------------------------------------------------------------

Summary of changes:
 Utilities/cmlibarchive/CMakeLists.txt              |    7 +++
 Utilities/cmlibarchive/build/cmake/config.h.in     |    3 +
 .../libarchive/archive_read_disk_entry_from_file.c |    3 +
 .../libarchive/archive_write_set_format_iso9660.c  |   42 ++++++++++----------
 4 files changed, 34 insertions(+), 21 deletions(-)


hooks/post-receive
diff --git a/Utilities/cmlibarchive/libarchive/archive_write_set_format_iso9660.c b/Utilities/cmlibarchive/libarchive/archive_write_set_format_iso9660.c
index 3cb2488..87136a6 100644
--- a/Utilities/cmlibarchive/libarchive/archive_write_set_format_iso9660.c
+++ b/Utilities/cmlibarchive/libarchive/archive_write_set_format_iso9660.c
@@ -6619,7 +6619,7 @@ isoent_collect_dirs(struct vdd *vdd, struct isoent *rootent, int depth)
  */
 static int
 isoent_rr_move_dir(struct archive_write *a, struct isoent **rr_moved,
-    struct isoent *isoent, struct isoent **newent)
+    struct isoent *curent, struct isoent **newent)
 {
 	struct iso9660 *iso9660 = a->format_data;
 	struct isoent *rrmoved, *mvent, *np;
@@ -6645,40 +6645,40 @@ isoent_rr_move_dir(struct archive_write *a, struct isoent **rr_moved,
 		*rr_moved = rrmoved;
 	}
 	/*
 	 * Make a clone of isoent which is going to be relocated
 	 * to rr_moved.
 	 */
-	mvent = isoent_clone(isoent);
+	mvent = isoent_clone(curent);
 	if (mvent == NULL) {
 		archive_set_error(&a->archive, ENOMEM,
 		    "Can't allocate memory");
 		return (ARCHIVE_FATAL);
 	}
 	/* linking..  and use for creating "CL", "PL" and "RE" */
-	mvent->rr_parent = isoent->parent;
-	isoent->rr_child = mvent;
+	mvent->rr_parent = curent->parent;
+	curent->rr_child = mvent;
 	/*
 	 * Move subdirectories from the isoent to mvent
 	 */
-	if (isoent->children.first != NULL) {
-		*mvent->children.last = isoent->children.first;
-		mvent->children.last = isoent->children.last;
+	if (curent->children.first != NULL) {
+		*mvent->children.last = curent->children.first;
+		mvent->children.last = curent->children.last;
 	}
 	for (np = mvent->children.first; np != NULL; np = np->chnext)
 		np->parent = mvent;
-	mvent->children.cnt = isoent->children.cnt;
-	isoent->children.cnt = 0;
-	isoent->children.first = NULL;
-	isoent->children.last = &isoent->children.first;
+	mvent->children.cnt = curent->children.cnt;
+	curent->children.cnt = 0;
+	curent->children.first = NULL;
+	curent->children.last = &curent->children.first;
 
-	if (isoent->subdirs.first != NULL) {
-		*mvent->subdirs.last = isoent->subdirs.first;
-		mvent->subdirs.last = isoent->subdirs.last;
+	if (curent->subdirs.first != NULL) {
+		*mvent->subdirs.last = curent->subdirs.first;
+		mvent->subdirs.last = curent->subdirs.last;
 	}
-	mvent->subdirs.cnt = isoent->subdirs.cnt;
-	isoent->subdirs.cnt = 0;
-	isoent->subdirs.first = NULL;
-	isoent->subdirs.last = &isoent->subdirs.first;
+	mvent->subdirs.cnt = curent->subdirs.cnt;
+	curent->subdirs.cnt = 0;
+	curent->subdirs.first = NULL;
+	curent->subdirs.last = &curent->subdirs.first;
 
 	/*
 	 * The mvent becomes a child of the rr_moved entry.
@@ -6691,7 +6691,7 @@ isoent_rr_move_dir(struct archive_write *a, struct isoent **rr_moved,
 	 * has to set the flag as a file.
 	 * See also RRIP 4.1.5.1 Description of the "CL" System Use Entry.
 	 */
-	isoent->dir = 0;
+	curent->dir = 0;
 
 	*newent = mvent;
 
@@ -6645,40 +6645,40 @@ isoent_rr_move_dir(struct archive_write *a, struct isoent **rr_moved,
 	}
 	/*
-	 * Make a clone of isoent which is going to be relocated
+	 * Make a clone of curent which is going to be relocated
 	 * to rr_moved.
 	 */
@@ -6645,40 +6645,40 @@ isoent_rr_move_dir(struct archive_write *a, struct isoent **rr_moved,
 	/*
-	 * Move subdirectories from the isoent to mvent
+	 * Move subdirectories from the curent to mvent
 	 */

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b6ca96ec95145b453790f519abbbae91cd6c9771
commit b6ca96ec95145b453790f519abbbae91cd6c9771
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Wed Jan 4 09:37:54 2012 -0500
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Wed Jan 4 09:39:28 2012 -0500

    libarchive: Include linux/types.h before linux/fiemap.h
    
    Some Linux API versions do not perform this inclusion automatically,
    so types like __u64 needed by the latter are not available.

-- 
CMake


More information about the Cmake-commits mailing list